# Generated by roxygen2: do not edit by hand

S3method(ph_with,dml)
S3method(sheet_add_drawing,dml)
export(body_add_vg)
export(dml)
export(dml_pptx)
export(dml_xlsx)
export(xl_add_vg)
import(systemfonts)
importFrom(Rcpp,sourceCpp)
importFrom(gdtools,font_family_exists)
importFrom(gdtools,font_set_auto)
importFrom(grDevices,dev.off)
importFrom(officer,fortify_location)
importFrom(officer,ph_location)
importFrom(officer,ph_location_type)
importFrom(officer,ph_with)
importFrom(officer,sheet_add_drawing)
importFrom(officer,xlsx_drawing)
importFrom(rlang,enquo)
importFrom(rlang,eval_tidy)
importFrom(xml2,as_xml_document)
importFrom(xml2,read_xml)
importFrom(xml2,xml_add_child)
importFrom(xml2,xml_find_all)
importFrom(xml2,xml_find_first)
useDynLib(rvg,.registration = TRUE)
